log

Function log 

pub fn log(level: Level, tag: &str, msg: &str)
Log a record with the given level, tag, and msg.

This is the only entry point for structured logging. The first call transparently initialises the log directory and file sink.

Per-sink level filtering

LevelConsole (default)File (default)
Debug
Info
Warn
Error

Override with SCRIBE_CONSOLE_LEVEL / SCRIBE_FILE_LEVEL.